@@ -11,7 +11,7 @@ import os
 import re
 import traceback
 from asyncio import Queue
-from typing import Callable, Any, Awaitable, Set, Optional
+from typing import Callable, Any, Awaitable, Set, Optional, Tuple
 
 import dotenv
 
@@ -105,7 +105,7 @@ async def _run_slapp(slapp_path: str, mode: str, restart_on_fail: bool = True):
             encoding=None,  # encoding must be None
             errors=None,  # errors must be None
             shell=True,
-            limit=100 * 1024 * 1024,  # 100 MiB
+            limit=200 * 1024 * 1024,  # 200 MiB (That's a lot for shell piping!)
         )
 
         slapp_loop = True
@@ -138,6 +138,17 @@ def conditionally_add_option(options, query: str, typed_option_no_delimit: str,
     return query.strip()
 
 
+def conditionally_add_limit(options, query: str) -> Tuple[str, bool]:
+    reg = re.compile(r"(--|–|—)limit (\d+)", re.IGNORECASE)
+    result = reg.search(query)
+    custom_limit = True if result else False
+    if custom_limit:
+        lim = result.group(2)
+        query = reg.sub('', query)
+        options.add("--limit " + lim)
+    return query.strip(), custom_limit
+
+
 async def query_slapp(query: str, limit: Optional[int] = 20):
     """Query Slapp. The response comes back through the callback function that was passed in initialise_slapp."""
     options: Set[str] = set()
@@ -151,6 +162,7 @@ async def query_slapp(query: str, limit: Optional[int] = 20):
     query = conditionally_add_option(options, query, 'clantag', 'queryIsClanTag')
     query = conditionally_add_option(options, query, 'team', 'queryIsTeam')
     query = conditionally_add_option(options, query, 'player', 'queryIsPlayer')
+    query, has_limit_option = conditionally_add_limit(options, query)
 
     # If this is a friend code query
     if query.upper().startswith("SW-"):
@@ -163,7 +175,7 @@ async def query_slapp(query: str, limit: Optional[int] = 20):
         except Exception as e:
             logging.debug(f"Query started with SW- but was not a friend code: {e} ")
 
-    if limit is not None:
+    if not has_limit_option and limit is not None:
         options.add(f"--limit {limit}")
 
     logging.debug(f"Posting {query=} to existing Slapp process with options {' '.join(options)} ...")
